DepSherpaCommandRunner class
Runs the dep_sherpa command-line interface.
Constructors
- DepSherpaCommandRunner({FileSystemAdapter? fileSystem, ProcessRunner? processRunner, HttpClientAdapter? httpClient, void stdoutWriter(String line)?, void stderrWriter(String line)?})
- Creates a command runner with injectable adapters for testing.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
run(
List< String> args, {String? workingDirectory}) → Future<int> -
Executes the CLI with
args. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- analysisFailure → const int
- Exit code for analysis failures.
- highRiskThresholdExceeded → const int
- Exit code for threshold violations.
- success → const int
- Exit code for successful completion.
- usageError → const int
- Exit code for invalid usage.