DarwinNativeLayout class
Filesystem signals found inside a Darwin platform directory.
- Annotations
-
- @immutable
Constructors
- DarwinNativeLayout({required String platform, required bool directoryExists, required bool hasPodfile, required bool hasPodfileLock, required bool hasPodspec, required bool hasClassesDirectory, required bool hasAssetsDirectory, required bool hasResourcesDirectory, required bool hasPackageSwift, required bool hasSourcesDirectory, required bool hasPrivacyManifest})
-
Creates a Darwin native layout snapshot.
const
Properties
- directoryExists → bool
-
Whether the platform directory exists.
final
- hasAssetsDirectory → bool
-
Whether
<platform>/Assets/exists.final - hasClassesDirectory → bool
-
Whether
<platform>/Classes/exists.final - hashCode → int
-
The hash code for this object.
no setterinherited
- hasPackageSwift → bool
-
Whether
<platform>/**/Package.swiftexists.final - hasPodfile → bool
-
Whether
<platform>/Podfileexists.final - hasPodfileLock → bool
-
Whether
<platform>/Podfile.lockexists.final - hasPodspec → bool
-
Whether
<platform>/*.podspecexists.final - hasPrivacyManifest → bool
-
Whether
<platform>/**/PrivacyInfo.xcprivacyexists.final - hasResourcesDirectory → bool
-
Whether
<platform>/Resources/exists.final - hasSourcesDirectory → bool
-
Whether
<platform>/**/Sources/exists.final - platform → String
-
Platform directory name, such as
ios,macos, ordarwin.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited