ProjectPackageType enum
The local project shape inferred from pubspec.yaml.
Values
- dartPackage → const ProjectPackageType
-
A Dart-only package or CLI.
- flutterPackage → const ProjectPackageType
-
A Flutter package that is not an app or plugin.
- flutterApp → const ProjectPackageType
-
A Flutter application.
- flutterPlugin → const ProjectPackageType
-
A Flutter plugin package.
- federatedFlutterPlugin → const ProjectPackageType
-
A federated Flutter plugin package.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
ProjectPackageType> - A constant List of the values in this enum, in order of their declaration.