FileSystemAdapter class abstract interface

Defines filesystem operations used by the package.

Implementers

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createDirectory(String path) → void
Creates the directory at path, including missing parents.
directoryExists(String path) → bool
Returns whether a directory exists at path.
fileExists(String path) → bool
Returns whether a file exists at path.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
readFile(String path) → String
Reads the UTF-8 contents of the file at path.
toString() → String
A string representation of this object.
inherited
writeFile(String path, String contents) → void
Writes contents to the file at path.

Operators

operator ==(Object other) → bool
The equality operator.
inherited