LocalFileSystemAdapter class
Uses dart:io to implement FileSystemAdapter.
- Implemented types
Constructors
- LocalFileSystemAdapter()
-
Creates a filesystem adapter backed by the local disk.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createDirectory(
String path) → void -
Creates the directory at
path, including missing parents.override -
directoryExists(
String path) → bool -
Returns whether a directory exists at
path.override -
fileExists(
String path) → bool -
Returns whether a file exists at
path.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
readFile(
String path) → String -
Reads the UTF-8 contents of the file at
path.override -
toString(
) → String -
A string representation of this object.
inherited
-
writeFile(
String path, String contents) → void -
Writes
contentsto the file atpath.override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited