LocalFileSystemAdapter constructor
const
LocalFileSystemAdapter()
Creates a filesystem adapter backed by the local disk.
Implementation
const LocalFileSystemAdapter();
Creates a filesystem adapter backed by the local disk.
const LocalFileSystemAdapter();