GithubService class abstract interface

Enriches package metadata using GitHub repository data.

Implementers

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

enrich(PackageHealth current, DepSherpaConfig config) → Future<PackageHealth>
Returns current augmented with GitHub data when available.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited