NullGithubService class

Disables GitHub enrichment and returns metadata unchanged.

Implemented types

Constructors

NullGithubService()
Creates a null GitHub service.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

enrich(PackageHealth current, DepSherpaConfig config) Future<PackageHealth>
Returns the input metadata unchanged.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited