OnlineGithubService class
Uses the GitHub API, with optional caching, to enrich repository metadata.
- Implemented types
Constructors
- OnlineGithubService(HttpClientAdapter _httpClient, CacheService _cacheService, String _cacheDir)
- Creates an online GitHub service.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
enrich(
PackageHealth current, DepSherpaConfig config) → Future< PackageHealth> -
Returns
currentenriched with GitHub metadata.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited