HttpResponseData class

Represents a basic HTTP response consumed by service adapters.

Constructors

HttpResponseData({required int statusCode, required String body, required Map<String, String> headers})
Creates an HTTP response data object.
const

Properties

body String
The decoded response body text.
final
hashCode int
The hash code for this object.
no setterinherited
headers Map<String, String>
Response headers normalized by the adapter.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statusCode int
The numeric status code returned by the server.
final

Methods

decodeJson() → dynamic
Decodes body as JSON.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited