SystemProcessRunner class

Uses dart:io Process.run to execute commands on the host system.

Implemented types

Constructors

SystemProcessRunner()
Creates a process runner backed by the current operating system.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
run(String executable, List<String> arguments, {String? workingDirectory, Duration timeout = const Duration(seconds: 30)}) Future<ProcessResultData>
Runs executable with arguments and returns the captured result.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited