NullPubApiService class
Disables pub.dev enrichment and always returns offline metadata.
- Implemented types
Constructors
- NullPubApiService()
-
Creates a null pub.dev service.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
fetch(
String packageName, DepSherpaConfig config) → Future< PackageHealth> -
Returns an offline-only health snapshot.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited