PubspecService class
Loads the root project's pubspec.yaml.
Constructors
- PubspecService(FileSystemAdapter _fs)
-
Creates a pubspec service.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
load(
String projectRoot, {ProjectIdentity? seedIdentity}) → ProjectManifest -
Loads the project manifest from
projectRoot. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited