MarkdownReportRenderer class
Renders scan reports as Markdown.
Constructors
- MarkdownReportRenderer()
-
Creates a Markdown report renderer.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
render(
ScanReport report) → String -
Renders
reportas Markdown. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited