ConfigService class
Loads and explains dep_sherpa.yaml configuration files.
Constructors
- ConfigService(FileSystemAdapter _fs)
-
Creates a configuration service.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
explain(
DepSherpaConfig config) → String -
Returns a formatted JSON explanation of
config. -
load(
{String? configPath, required String projectRoot}) → DepSherpaConfig -
Loads configuration for
projectRoot, optionally overriding the path. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited