ProjectIdentity class
The project identity used by the trust model.
- Annotations
-
- @immutable
Constructors
- ProjectIdentity({String? publisher, String? githubOrg, String? repositoryUrl})
-
Creates a project identity.
const
Properties
- githubOrg → String?
-
The expected GitHub organization for trusted packages.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- publisher → String?
-
The expected pub.dev publisher for trusted packages.
final
- repositoryUrl → String?
-
The project repository URL.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> - Serializes the project identity.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited