RiskParameters class
Numerical parameters used by the risk model formulas.
- Annotations
-
- @immutable
Constructors
- RiskParameters({required double majorLagWeight, required double minorLagWeight, required double patchLagWeight, required double kLag, required double kAge, required double fMax, required double kFreq, required double beta, required double lMax, required double gamma, required double qMax, required double cMax, required double kContributors, required double kDepth, required double kTransitive, required double eta})
-
Creates risk-model parameters.
const
- RiskParameters.defaults()
-
Returns the default formula parameters.
factory
Properties
- beta → double
-
Blend factor between publish age and release frequency.
final
- cMax → double
-
Maximum contributor count used for the bus-factor proxy.
final
- eta → double
-
Blend factor between depth risk and transitive-count risk.
final
- fMax → double
-
Maximum releases-per-month contribution.
final
- gamma → double
-
Blend factor between popularity and likes.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- kAge → double
-
Decay constant for publish age.
final
- kContributors → double
-
Decay constant for contributor count.
final
- kDepth → double
-
Decay constant for graph depth.
final
- kFreq → double
-
Decay constant for release frequency.
final
- kLag → double
-
Decay constant for version lag.
final
- kTransitive → double
-
Decay constant for transitive dependency count.
final
- lMax → double
-
Maximum likes value used in normalization.
final
- majorLagWeight → double
-
Weight applied to major version lag.
final
- minorLagWeight → double
-
Weight applied to minor version lag.
final
- patchLagWeight → double
-
Weight applied to patch version lag.
final
- qMax → double
-
Maximum pub points value used in normalization.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited