DarwinNativeLayout class

Filesystem signals found inside a Darwin platform directory.

Annotations
  • @immutable

Constructors

DarwinNativeLayout({required String platform, required bool directoryExists, required bool hasPodfile, required bool hasPodfileLock, required bool hasPodspec, required bool hasClassesDirectory, required bool hasAssetsDirectory, required bool hasResourcesDirectory, required bool hasPackageSwift, required bool hasSourcesDirectory, required bool hasPrivacyManifest})
Creates a Darwin native layout snapshot.
const

Properties

directoryExists bool
Whether the platform directory exists.
final
hasAssetsDirectory bool
Whether <platform>/Assets/ exists.
final
hasClassesDirectory bool
Whether <platform>/Classes/ exists.
final
hashCode int
The hash code for this object.
no setterinherited
hasPackageSwift bool
Whether <platform>/**/Package.swift exists.
final
hasPodfile bool
Whether <platform>/Podfile exists.
final
hasPodfileLock bool
Whether <platform>/Podfile.lock exists.
final
hasPodspec bool
Whether <platform>/*.podspec exists.
final
hasPrivacyManifest bool
Whether <platform>/**/PrivacyInfo.xcprivacy exists.
final
hasResourcesDirectory bool
Whether <platform>/Resources/ exists.
final
hasSourcesDirectory bool
Whether <platform>/**/Sources/ exists.
final
platform String
Platform directory name, such as ios, macos, or darwin.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited