DarwinProjectAnalysis class
Complete local Darwin readiness detector output.
- Annotations
-
- @immutable
Constructors
-
DarwinProjectAnalysis({required ProjectPackageType projectPackageType, required FlutterPluginPlatformInfo pluginPlatforms, required Map<
String, DarwinNativeLayout> nativeLayouts, required NativeDependencyManager nativeDependencyManager}) -
Creates a project-level Darwin analysis snapshot.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- nativeDependencyManager → NativeDependencyManager
-
Inferred Darwin native dependency manager.
final
-
nativeLayouts
→ Map<
String, DarwinNativeLayout> -
Native layout snapshots keyed by platform directory.
final
- pluginPlatforms → FlutterPluginPlatformInfo
-
Parsed Flutter plugin platform declarations.
final
- projectPackageType → ProjectPackageType
-
Inferred project package type.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited