FlutterPluginPlatformInfo class
Parsed Flutter plugin platform declarations for Darwin targets.
- Annotations
-
- @immutable
Constructors
-
FlutterPluginPlatformInfo({required Set<
String> platforms, required bool federated}) -
Creates Flutter plugin platform information.
const
Properties
- federated → bool
-
Whether any platform entry points at a default package implementation.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
platforms
→ Set<
String> -
Platform keys declared under
flutter.plugin.platforms.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- supportsAnyDarwin → bool
-
Whether any Darwin platform is declared.
no setter
- supportsDarwin → bool
-
Whether the plugin declares shared Darwin support.
no setter
- supportsIos → bool
-
Whether the plugin declares iOS support.
no setter
- supportsMacos → bool
-
Whether the plugin declares macOS support.
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited