NativeDependencyManager enum

Native dependency manager detected from Darwin platform files.

Inheritance
Available extensions

Values

none → const NativeDependencyManager

No native dependency manager is applicable.

cocoapods → const NativeDependencyManager

CocoaPods-only native layout.

swiftPackageManager → const NativeDependencyManager

Swift Package Manager-only native layout.

mixed → const NativeDependencyManager

Both CocoaPods and Swift Package Manager files are present.

unknown → const NativeDependencyManager

Darwin plugin support exists, but no native dependency files were found.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<NativeDependencyManager>
A constant List of the values in this enum, in order of their declaration.