DependencyNode class

Describes a package node discovered in the dependency graph.

Annotations
  • @immutable

Constructors

DependencyNode({required String name, required String version, required String kind, required List<String> dependencies, required bool isDirect, required bool isDevDependency, DependencySource source = DependencySource.unknown})
Creates a dependency node.
const

Properties

dependencies List<String>
Direct child package names.
final
hashCode int
The hash code for this object.
no setterinherited
isDevDependency bool
Whether the package is declared under dev_dependencies.
final
isDirect bool
Whether the package is a direct dependency of the project.
final
isSdkPackage bool
Whether this package is provided by an SDK.
no setter
kind String
The dependency kind reported by dart pub deps.
final
name String
The package name.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source DependencySource
The dependency source reported by pubspec.lock.
final
version String
The resolved package version.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Serializes this node for reports.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited