DependencyProfile class
Combines graph data, metadata, and local dependency information.
- Annotations
-
- @immutable
Constructors
- DependencyProfile({required DependencyNode node, required DependencyGraphMetrics metrics, required PackageHealth health})
-
Creates a dependency profile.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- health → PackageHealth
-
Enriched package metadata.
final
- metrics → DependencyGraphMetrics
-
Graph metrics derived from the dependency graph.
final
- node → DependencyNode
-
The local dependency graph node.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> - Serializes this profile for reports.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited