GraphService class
Calculates graph metrics and summaries for dependencies.
Constructors
- GraphService()
-
Creates a graph service.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
analyze(
Map< String, DependencyNode> nodes) → Map<String, DependencyGraphMetrics> -
Computes per-dependency graph metrics for
nodes. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
summarize(
Map< String, DependencyNode> nodes) → GraphSummary - Builds a high-level summary for the full dependency graph.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited