Defines the subset of HTTP functionality required by the package.
- Implementers
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
get(
Uri uri, {Map< String, String> headers = const <String, String>{}, Duration timeout = const Duration(seconds: 5)}) → Future<HttpResponseData> -
Executes an HTTP GET request for
uri. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited