ProcessResultData class

Represents the result of a completed process invocation.

Constructors

ProcessResultData({required int exitCode, required String stdout, required String stderr})
Creates a process result container.
const

Properties

exitCode int
The process exit code.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stderr String
The collected standard error text.
final
stdout String
The collected standard output text.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited