ProjectManifest class
The local project manifest data required for dependency analysis.
- Annotations
-
- @immutable
Constructors
-
ProjectManifest({required String name, required String? version, required Set<
String> dependencies, required Set<String> devDependencies, required String? environmentSdk, required bool usesFlutter, required ProjectIdentity projectIdentity}) -
Creates a project manifest.
const
Properties
-
dependencies
→ Set<
String> -
The direct runtime dependencies.
final
-
devDependencies
→ Set<
String> -
The direct development dependencies.
final
- environmentSdk → String?
-
The project SDK constraint.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
The package name from
pubspec.yaml.final - projectIdentity → ProjectIdentity
-
The identity used for trust decisions.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- usesFlutter → bool
-
Whether the package depends on Flutter.
final
- version → String?
-
The package version from
pubspec.yaml.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited