DependencyRiskEntry class
A scored dependency entry included in a scan report.
Constructors
- DependencyRiskEntry({required DependencyProfile dependency, required RiskScore riskScore})
-
Creates a report entry for a scored dependency.
const
Properties
- dependency → DependencyProfile
-
The analyzed dependency profile.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- riskScore → RiskScore
-
The computed risk score and transparency data.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> - Serializes this report entry.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited