GraphSummary class

High-level graph metrics for the scanned project.

Constructors

GraphSummary({required int maxDepth, required int totalNodes, required int directDependencyCount, required int transitiveDependencyCount, required List<Map<String, Object?>> centralNodes})
Creates a graph summary.
const

Properties

centralNodes List<Map<String, Object?>>
The most central graph nodes.
final
directDependencyCount int
The number of direct dependencies in the project.
final
hashCode int
The hash code for this object.
no setterinherited
maxDepth int
The deepest path found in the project graph.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalNodes int
The total number of packages discovered.
final
transitiveDependencyCount int
The number of transitive-only dependencies in the project.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Serializes the graph summary.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited