RiskComponents class
Normalized risk components derived from RiskSignals.
- Annotations
-
- @immutable
Constructors
Properties
- adoption → double
-
The normalized adoption risk.
final
- busFactor → double
-
The normalized bus-factor risk.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- maintenance → double
-
The normalized maintenance risk.
final
- quality → double
-
The normalized quality risk.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- transitive → double
-
The normalized transitive-impact risk.
final
- versionLag → double
-
The normalized version-lag risk.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, double> - Serializes the risk components.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited