ScoringService class
Computes dependency risk scores and applies the trust model.
Constructors
- ScoringService()
-
Creates a scoring service.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
score(
{required DependencyProfile dependency, required ProjectManifest project, required DepSherpaConfig config}) → RiskScore -
Scores
dependencyin the context ofprojectandconfig. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited